package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(/@`````````0```````
M`*%0``````!``#@`"`!``!8`%0````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)=@````````EV``
M```````0``````$````&````````F_````````"K\````````*OP````````
M!(@````````4Z````````!```````@````8```````"<$````````*P0````
M````K!`````````!H`````````&@``````````AD=.50````!````````)%P
M````````D7````````"1<`````````#4`````````-0`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````";\````````*OP````````J_`````````$
M$`````````00``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````1@````0````(@`1`!0`0$""$`(:`!!``*`D$``D``"&""`($ND$8@(@`
M````````1@```$H```!.````3P```%4```!6````5P````````!9````6@``
M``````!;````7````%X``````````'R:?VH.[]/J+4?>SA_?Q6^VF\4N#O&-
MN'S49-0.Y/\A'%AQV6!LH?HL/^7";XL!LH?7^D(!QD?B?)+CN](\PU5FS*]G
MTW`'B.S514/MVV(SS"6,%9N<J7\*`J?@4)X::TG[X*,`````````````````
M`````````````````````P``!P```````!>P```````````````!$@``````
M```````````````````````)$0````````````````````````````&N$0``
M``````````````````````````%*$@`````````````````````````````0
M$@````````````````````````````&'$@``````````````````````````
M```8$@`````````````````````````````?$@``````````````````````
M``````&[$@````````````````````````````&3$@``````````````````
M```````````H(`````````````````````````````+*(0``````````````
M``````````````!`$@````````````````````````````!&$@``````````
M``````````````````*7$@````````````````````````````*($@``````
M``````````````````````'A$@````````````````````````````!-$@``
M``````````````````````````)G$@````````````````````````````!4
M$@````````````````````````````!<$@``````````````````````````
M``)0$@````````````````````````````!D$@``````````````````````
M``````!J$@````````````````````````````!S(```````````````````
M``````````*!$@````````````````````````````"/$@``````````````
M``````````````"4$@````````````````````````````',$0``````````
M``````````````````)N$@````````````````````````````(.$@``````
M``````````````````````";$@````````````````````````````(`$@``
M``````````````````````````,.$@````````````````````````````+)
M$0````````````````````````````(R$@``````````````````````````
M``*V$@````````````````````````````++$0``````````````````````
M``````"B$@````````````````````````````*N$@``````````````````
M``````````%8$@````````````````````````````"K(@``````````````
M``````````````"Z(`````````````````````````````#0$@``````````
M``````````````````)Y$@````````````````````````````(>$@``````
M``````````````````````#5$@````````````````````````````#;(```
M``````````````````````````);$@````````````````````````````#U
M$@````````````````````````````%X$@``````````````````````````
M``#Z$@````````````````````````````)`$@``````````````````````
M``````%G$@````````````````````````````$`$@``````````````````
M``````````$1$@````````````````````````````'<$@``````````````
M``````````````!E$@````````````````````````````'M$@``````````
M``````````````````(G$@````````````````````````````*G$@``````
M``````````````````````$7$@````````````````````````````*?$@``
M``````````````````````````$K$@````````````````````````````'7
M$@````````````````````````````$R$@``````````````````````````
M``+((0````````````````````````````%#$@``````````````````````
M``````+#$@``"0```````![X`````````?P```&H$@``"@```````%'P````
M``````(```-0$@``"0```````#!(````````!C@```/\$@``"0```````#D(
M`````````&@```,M$@``"0```````"HX``````````8```.Z$@``!P``````
M`!>P``````````(```-S$@``"0```````#:``````````H0```/@$@``"0``
M`````"I``````````=P```.K$```$P```````+!X``````````````,^$@``
M"0```````"^8`````````*P```-=$@``"0```````"B8`````````#P```-E
M$@``"0```````"[X`````````&P```.)$@``"0```````$\P`````````5``
M``.>$@``"0```````"P@`````````"(```/W$```$P```````,#8````````
M``````+S$@``"0```````"$H`````````#P```/`$@``"0```````"Q(````
M`````2(```.4$0``$@```````+!P``````````@```/9$```$@```````+!X
M``````````````.P$@``"0```````"#X``````````````.W$@``"0``````
M`$[``````````&P```+\$@``"0```````"]H`````````"P```,7$@``"0``
M`````"DX`````````/X```/M$@``"0```````%"``````````18```/,$@``
M"0```````"UP`````````8(`;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E
M<W,`<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T
M<&ED`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE4
M35]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!R
M96%D;&EN:P!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`
M97AI=`!C;&]S90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD
M:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC
M`&UE;6-P>0!?7W-T86-K7V-H:U]F86EL`&=E='5I9`!097)L7W-Y<U]T97)M
M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`7V9I;FD`4$Q?
M9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D
M97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S
M>7-M86QL;V,`<&5R;%]A;&QO8P!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T
M9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T
M87)T7VUA:6X`7U]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"US,SDP
M>"YS;RXQ`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U
M<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`
M6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A
M<E]B87-E;F%M90!?7V)S<U]S=&%R=`!S:&%?:6YI=`!P87)?9&ER;F%M90!P
M87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`7V5N
M9`!P87)?8VQE86YU<``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210``
M`````````*^(``````````P````````>^````````*^@``````````P`````
M``!1\````````*^X``````````P````````7L````````+````````````P`
M``````"P`````````+`0``````````P```````!4Z````````+`8````````
M``P```````!2$@```````+`H``````````P```````!2_@```````+`P````
M``````P```````!3`@```````+`X``````````P```````!4W````````+!`
M``````````P```````!29````````+!(``````````P```````!4Y```````
M`+!8``````````P```````!4S````````+!@``````````P```````!4T@``
M`````+!P``````````P```````!4[@```````*^0`````P````H`````````
M`````````*^8````!`````H``````````````````*^H````#`````H`````
M`````````````*^P````&@````H``````````````````*_`````'@````H`
M`````````````````*_(````)P````H``````````````````*_0````*P``
M``H``````````````````*_8````+`````H``````````````````*_@````
M,0````H``````````````````*_H````-@````H``````````````````*_P
M````-P````H``````````````````*_X````/`````H`````````````````
M`*W(`````@````L``````````````````*W0````!0````L`````````````
M`````*W8````!@````L``````````````````*W@````!P````L`````````
M`````````*WH````"`````L``````````````````*WP````"0````L`````
M`````````````*WX````"@````L``````````````````*X`````"P````L`
M`````````````````*X(````#`````L``````````````````*X0````#@``
M``L``````````````````*X8````#P````L``````````````````*X@````
M$`````L``````````````````*XH````$0````L``````````````````*XP
M````$@````L``````````````````*XX````$P````L`````````````````
M`*Y`````%`````L``````````````````*Y(````%0````L`````````````
M`````*Y0````%@````L``````````````````*Y8````%P````L`````````
M`````````*Y@````&`````L``````````````````*YH````&0````L`````
M`````````````*YP````&P````L``````````````````*YX````'`````L`
M`````````````````*Z`````'0````L``````````````````*Z(````'P``
M``L``````````````````*Z0````(`````L``````````````````*Z8````
M(0````L``````````````````*Z@````(@````L``````````````````*ZH
M````(P````L``````````````````*ZP````)0````L`````````````````
M`*ZX````)@````L``````````````````*[`````*`````L`````````````
M`````*[(````*0````L``````````````````*[0````*@````L`````````
M`````````*[8````*P````L``````````````````*[@````+`````L`````
M`````````````*[H````+0````L``````````````````*[P````+@````L`
M`````````````````*[X````+P````L``````````````````*\`````,```
M``L``````````````````*\(````,@````L``````````````````*\0````
M,P````L``````````````````*\8````-`````L``````````````````*\@
M````-0````L``````````````````*\H````.`````L`````````````````
M`*\P````.0````L``````````````````*\X````.@````L`````````````
M`````*]`````.P````L``````````````````*](````/0````L`````````
M`````````*]0````/@````L``````````````````*]8````/P````L`````
M`````````````*]@````0`````L``````````````````*]H````00````L`
M`````````````````*]P````0@````L``````````````````*]X````0P``
M``L``````````````````*^`````10````L``````````.OO\'``)+D$``^G
M^_]@XP#P```DP.4```5RP.4``!SGZ^_Q$``$!_[C$/`X`"3`$```2NG2!_`P
M$`CC$!`0``0'\0<`!P`'`,`0``!*Z.,0$```!`?Q#1#C$!`,`!3`]/___^4`
M````P!```$K<XQ`0```$!_$-$.,0$`P`%,#T____U0```!C`$```2M#C$!``
M``0'\0T0XQ`0#``4P/3____%````,,`0``!*Q.,0$```!`?Q#1#C$!`,`!3`
M]/___[4```!(P!```$JXXQ`0```$!_$-$.,0$`P`%,#T____I0```&#`$```
M2JSC$!````0'\0T0XQ`0#``4P/3___^5````>,`0``!*H.,0$```!`?Q#1#C
M$!`,`!3`]/___X4```"0P!```$J4XQ`0```$!_$-$.,0$`P`%,#T____=0``
M`*C`$```2HCC$!````0'\0T0XQ`0#``4P/3___]E````P,`0``!*?.,0$```
M!`?Q#1#C$!`,`!3`]/___U4```#8P!```$IPXQ`0```$!_$-$.,0$`P`%,#T
M____10```/#`$```2F3C$!````0'\0T0XQ`0#``4P/3___\U```!",`0``!*
M6.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@P!```$I,XQ`0```$!_$-$.,0
M$`P`%,#T____%0```3C`$```2D#C$!````0'\0T0XQ`0#``4P/3___\%```!
M4,`0``!*-.,0$```!`?Q#1#C$!`,`!3`]/___O4```%HP!```$HHXQ`0```$
M!_$-$.,0$`P`%,#T___^Y0```8#`$```2ASC$!````0'\0T0XQ`0#``4P/3_
M__[5```!F,`0``!*$.,0$```!`?Q#1#C$!`,`!3`]/___L4```&PP!```$H$
MXQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`$```2?CC$!````0'\0T0XQ`0
M#``4P/3___ZE```!X,`0``!)[.,0$```!`?Q#1#C$!`,`!3`]/___I4```'X
MP!```$G@XQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`$```2=3C$!````0'
M\0T0XQ`0#``4P/3___YU```"*,`0``!)R.,0$```!`?Q#1#C$!`,`!3`]/__
M_F4```)`P!```$F\XQ`0```$!_$-$.,0$`P`%,#T___^50```EC`$```2;#C
M$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0``!)I.,0$```!`?Q#1#C$!`,
M`!3`]/___C4```*(P!```$F8XQ`0```$!_$-$.,0$`P`%,#T___^)0```J#`
M$```28SC$!````0'\0T0XQ`0#``4P/3___X5```"N,`0``!)@.,0$```!`?Q
M#1#C$!`,`!3`]/___@4```+0P!```$ETXQ`0```$!_$-$.,0$`P`%,#T___]
M]0```NC`$```26CC$!````0'\0T0XQ`0#``4P/3___WE```#`,`0``!)7.,0
M$```!`?Q#1#C$!`,`!3`]/___=4```,8P!```$E0XQ`0```$!_$-$.,0$`P`
M%,#T___]Q0```S#`$```243C$!````0'\0T0XQ`0#``4P/3___VU```#2,`0
M``!)..,0$```!`?Q#1#C$!`,`!3`]/___:4```-@P!```$DLXQ`0```$!_$-
M$.,0$`P`%,#T___]E0```WC`$```22#C$!````0'\0T0XQ`0#``4P/3___V%
M```#D,`0``!)%.,0$```!`?Q#1#C$!`,`!3`]/___74```.HP!```$D(XQ`0
M```$!_$-$.,0$`P`%,#T___]90```\#`$```2/SC$!````0'\0T0XQ`0#``4
MP/3___U5```#V,`0``!(\.,0$```!`?Q#1#C$!`,`!3`]/___44```/PP!``
M`$CDXQ`0```$!_$-$.,0$`P`%,#T___]-0``!`C`$```2-CC$!````0'\0T0
MXQ`0#``4P/3___TE```$(,`0``!(S.,0$```!`?Q#1#C$!`,`!3`]/___14`
M``0XP!```$C`XQ`0```$!_$-$.,0$`P`%,#T___]!0``!%#`$```2+3C$!``
M``0'\0T0XQ`0#``4P/3___SU```$:,`0``!(J.,0$```!`?Q#1#C$!`,`!3`
M]/___.4```2`P!```$B<XQ`0```$!_$-$.,0$`P`%,#T___\U0``!)C`$```
M2)#C$!````0'\0T0XQ`0#``4P/3___S%```$L,`0``!(A.,0$```!`?Q#1#C
M$!`,`!3`]/___+4```3(P!```$AXXQ`0```$!_$-$.,0$`P`%,#T___\I0``
M!.#`$```2&SC$!````0'\0T0XQ`0#``4P/3___R5```$^,`0``!(8.,0$```
M!`?Q#1#C$!`,`!3`]/___(4```40P!```$A4XQ`0```$!_$-$.,0$`P`%,#T
M___\=0``!2CK;_`P`"3C\/](_W'C,/"H`"3C0/"@`"10(/"T04#PH$$P\*A!
M(/"TP.7___Y\Q$@``$AIQ"@``$ABN00`-,#E___](<08``!(+I4`$`"G=``>
MP.7___W7Q"L``$C`["8`"`!\IRD``<#E___^C,#E___^Z<08``!(*N,@$```
M%L#E____8)(`*B?$N```2!_C(+```!;`Y?___U66`B1ZXR"P```6P.7___]-
ME@$D>E@@\+3LL@`#`-BG*@`$N10`(NLB``,`#<#E___^G.-`\*@`!.,00```
M!.,0(```),`0```:=N,0(`@`),08``!(1N,0(!``),`0```:;.,0(!@`)+D$
M`%+$*P``2&"G&``!XR#PM``2N?+0(:<Y``#L$P`$`-BG.P`!N10`$>L1``,`
M#;D(`!6G)@!7N10`2^5($````*=I``#`,```!$O$*```2$3`Y?___/48LNPF
M``H`?L0H``!(.L#E___^*QBRQ"@``$@SP.7___V4P"```!D=P.4```&:["8`
M'P!\P!```$@@XQ`0```"IW0`"\`@```8Y,#E```!B<0K``!($L`0``!(#^,@
M$````J>$``7`Y0``#"?$*```2`C`Y?___NG`Y?__^Z:Y%``KZV_PZ``$!_[K
MHP`#``WC"D````3C`!```"2G]/^4!P<'![D$`"_`,````!+C,#```!BG^_]@
MIPD``.,`\```),#T````"0<'!P<``(KP!P<'!^MO\#``)$%`(`CC\/]8_W'$
M:```1S3E2/"@``#$6```1SKC,"`$`!3$*```1QS`Y?___3'K;_#8``0'_@<'
M!P?`$```1XC`(```1X7L$@`*@&3$&```1QOL&``$`'P'\0?^!P<'!P<'P"``
M`$=TP!```$=QN0D`$NLA``,`"NLQ`#\`#+D(`#+K,P`!``KL.``-`'S$&```
M1Q+L&``'`'S`(```1U@'\0?^!P<'!P<'ZY_P2``DP)```$=-X_#_8/]QE0"0
M`*=T`$O`$```1N_C$!````*GA``(Q"@``$;_P.7___T8P!```$3YP+```$3Z
MP*```$3SN0D`L<08``!'+NN[``,`"J>[___L&P`5H&6G&P`!Q!L``$<AZQ$`
M`P`-XQ&@```$#>'$&```1Q?L&__Q0&7`Y?___X7`$```1J+C$!````*GA``(
MP"```#?JP.7___L_D@&0`.N?\.@`!`?^!P<'!^OO\'``)./P_V#_<>OO\1``
M!`?^!P<'!\`0``!&F.,0$````J>$`!?K[_!P`"3`,```1N7C\/]@_W'`(```
M-[_`Y?___,3K[_$0``3`]/___UK`]/___U?K[_!P`"3C\/]@_W'K[_$0``0'
M_@<'!P?K;_`P`"3C\/]@_W'L*`!-`'S$&```1EOCH!````*GA`!$N00`8[D$
M`(*Y!`!"XQ!```"4[!8`+@!^&TBY!`!ZN10`E..P<````J>$`!VY!`!)N00`
M.+D$`"O`Y?__^U_L)@`?`'Y!&;``E3T0`*=T`!BYZ:"G0;FP`>NJ``,`"E"@
M8`"Y!``KZV_PT``$!_[L&/_5/7Y!0$`!I_3_RD%P<`BG]/_1I[D``*?T_^T'
M!^N_\%@`)./P_U#_<;)/`+!!,/"DZ[L`(``-LD\`L=('\*BP*,#E____EM4'
M\*BP**>$``7`Y?___6KKO_$(``0'_@<'!P<'!^N?\$@`)./P_U#_<;)/`*#K
MJ@`@``VR3P"AN00`LM('\*B@*$&0\*2Y!``YN00`*\#E____;.PF``L`?-4'
M\*B@**>$`![`Y?___3WC$/"D`!3$*```1;_K$0`#``WC$"````CC(!`(``3C
M(!```"3L*/_<`'Q!$!`(I_3_]>N?\/@`!`?^!P?K;_`P`"3C\/[(_W&R3P"0
MZYD`(``-LD\`D=('\3"0*.PH`"<`?+D$`**5`"``IX0`(,#E___YH[D$`'+L
M*``9`'Q!8/"@N00`)\#E___Z1[D$`++L)@`5`'RY!``GP.7___K-N00`*L#E
M___\.-4'\3"0**>$`&[`Y?___.!!L+`3P!```!:(IP@``+D$`"NR70`2IQ3_
M_J>$_]?`$```%GRY!``KLET`$J<4__ZGA/_,N00`*J<9``"R7@`2IQ3__KD$
M`#NY"0`:IRD``+)>`".G%/_^N0D`*QH2IQH``KD4`"'`Y?__^CK`,```%E>Y
M!`""N00`6[D$`$K`Y?___&ZY!``VN00`*,#E___\)^PH`!G_?E@0\+BG*$``
MP!L``/``[!(`#V!VN00`*,#E____:;D$`"C`Y?___`"G]/^$N00`*,#E___Y
M^:?T__3K;_%H``0'_NNO\%``)./P_LC_<;)/`+"Y!`"BZ[L`(``-03#PH+)/
M`+'2!_$PL"C`Y?__^BSL)@`I`'X8$J<X0`!8(/"XP"L``/``[",`"(!VI3^@
M`.PC``]@=J<Y``*Y!``JP.7___DB$!*G&O__B!``']4'\3"P*+D4`"&GA``)
MP.7___PSIQ@``*?T__3KK_&(``0'_NMO\#``)./P_U#_<;)/`'#K=P`@``VR
M3P!QN00`HM('\*AP*+D$`+.5/3``IW0`!$&P,`&G"```N00`&Z>9``!!,/"D
MLEX`D:<4__ZY!``JN0D`F\#E___^(NPH`"8`?*<(``"G&0``N00`,K)>`!.G
M%/_^N0D`$NR1`%\@9:<9``#C,;```)!",2``IQL``>PV__D`?-4'\*AP**>$
M`,/`Y?__^]C$&```1%WCT!````2G&0``&(&G&P`!ZR$``P`-XR+?^/\"IW3_
M]^PH``(`V,`0``!$O[D4`"+C$!```!+K(@`#``VGA`!YN00`,KD$`"W`Y?__
M^&[$&```1#/C(!```"3L*/_(`'SL&``!`-C$*```1">Y%``1XR`@```$ZQ$`
M`P`-4(#PI$$1(`#E2!````"Y!``:XR`0``"4["@`!@!^["8`:CU^N0D`&NPI
M``(`V;D8`"'C@/"D`!3$:```1`#KB``#``VY!`#8X]!@```(P.7___C]XR#0
M```D["C_B@!\XQ!@```$XQ@0```$XR"@``"00B`0`$&@H`&Y!``QP"L```#_
M01`0`:>$``7L)O_P/7Z2/3``IRD``.,RL```D$(R$`"G*P`![#;_^0!\I_3_
M8,`0``!$.^5,$````<#E___XQ;D$`&+L*/]3`'RY%`!(N00`/>M$``,`#<#E
M___XQL08``!#J^-@$```)*?T_WM!$!`!I_3_CNMO\.``!`?^!P<'!P<'Z^_P
M<``DQ!@``$.1X_#_8/]QXR`0```6P.7___K$P%```#1'Q$@``$.6P#```!2N
MZ^_Q$``$P/3___J5!P<'!^MO\#``)./P_UC_<<2X``!#;N,@L```%L!@```5
MZ<#E___ZH<#E____SN,@L```%L#E___ZF+D$`%;E2/"@``#`0```!K3`,```
M%([`Y?__]\KK;_#8``0'_@<'!P<'!^MO\#``)./P_U#]<>,0\*@"<;)/`'#K
M=P`@``VR3P!QT@<0`'`HP.7___?M0;#PIKD$`%+`8```%'+`0```%'&G.1`!
MN00`*\#E___WC.PF`!#_?J>Y``#C$/"H`G'5!Q``<"BGA`!'P.7___J,["`0
M`"!QXZ#PIP%QITD0`+D$`#JY!``KP.7___D-N00`DNPD_^(`?J<J``&Y%``B
MP.7___@!N00`LNPH_]8`?+D4`(GL*@`'H&6YZ(`2N6%`H>RZ``?`9;GH@!JY
M84"Q[)`0`2!RN00`2+D$`#JY!``KP.7___HP01BP`)(`$`"G]/^UN00`*^MO
M\.`"!`?^!P?`]/___X`'!^MO\#``)./P_L#^<>,0\3@!<;D$`+*Y!`!SLD\`
M@,`@```4`>N(`"``#;)/`('2!Q``@"C`Y?___)ZG.0`ON00`DKD$`"O`Y?__
M^%GL*``6`'RY!``[P"```!/JP.7___WFXQ#Q.`%QU0<0`(`HIX0`L<#E___Z
M`Z<(``"Y!``;N00`)Z>I``"R7@"AIQ3__D%P\3C`Y?__]^(;J\`P```3SJ>J
M``'`Y?__^9E!T/"HN00`4NQ8_\\`?)4`4`#`$```$XJYXH!1[)@`&P!\IP@`
M`+D$`!6Y!``ILET`$J<4__ZG=``.P#```!.IIRD``,#E___Y=+D$`%*G]/_=
MIP@``*<9``"Y!``ELEX`$J<4__X;%>PQ__\`V+D$`"6Y&``CE2\@`*>$`"$:
M&J<H#__L$O^1(';CL/"@`"3`8```$W_`0```$^^G.1``N00`)\#E___VA*<8
M$`"G*@`!["$`"L!WI_0``9(`(``8$Z?T_].Y!``]N00`)\#E___Y#^PF_[,`
M?E@0\,"E+X``P!L``/``[!+_J6!VISD``;D$`"?`Y?__]DOL)O^?`'ZY!``W
MP"```!,\P.7___TXN00`)\#E___W2[D$`+*G]/]+N00`*^MO\7`!!`?^!P<'
M![D$`!+C,!```)3L-@`$`'X'_D$0$`&G/@`ON>*`(:?T__,'!P<'!P?L*``)
M`'RY!``RE0`@`*=T``C`(```$MS`]/__]QRG"```IQD``+)>`!*G%/_^XT`?
M__]QN>DP(>PT``8@9>PV``7_?*<I``&G)P`3[#0`*F!DE2\P`*>$_][`(```
M$NRG]/_<XT!/__]QI_3_[Y4O0`"GA/_YN>DP%*<;``&Y(0`TIRD``;GB,!*G
M%P`$I_3_W^,@3___<94O0`"G=``VN>DP%.,@3___<>PR``8@9>PV``7_?*<9
M``'C0$___W&G%P`HN0D`0Z<I$`#L%``"`-GL$@`E(&7K[_!P`"2G2P`!X_#_
M8/]Q[$`0`"!QP"```$'1P.7___=>P"```$'+Z^_Q$``$!_ZY!`!"I_3_OY4O
M0`"GA/_3I_3_UJ<I```'_@<'!P<'!^N_\%@`),`0```QY^/P_S#_<;)/`+#K
MNP`@``VR3P"QT@?PR+`HTB'PIA`*P"```!)PP.7___LKP"```!)OP.7___LE
MP"```!)MP.7___L?P"```!)LP.7___L9P"```!)JP.7___L3P"```!)LP.7_
M__L-P"```!(^P.7___L'P"```!)FP.7___L!P"```!)EP.7___K[P"```!)D
MP.7___KUP"```!(KP.7___KOP"```!)=P.7___K%["@`"P!\N00`,L`@```2
M2,#E___\%L`@```25<#E___ZM+D$`#+L*``)`'S`(```$E/`Y?___`7`(```
M$E/`Y?__^J.Y!``R["@`&@!\P"```!'SP.7___OTP#```!)9P"```!(*P.7_
M__OKU0?PR+`HIX0`)L#E___X"\`@```2.<#E___Z@;D$`#+L*``(`'S`(```
M$?^G]/_>ITD`"L`P```2,$$@\+?`Y?__]:'L)O_5`'Y!,/#!I_3_[.N_\2@`
M!`?^!P<'!P<'Q!T``$"(IQ[__Z=T`"WK[_!P`"3`(```$=CC\/]@_W'`Y?__
M^DSL*``;`'R_$2``IX0`%L`7````,+F$`!&Y`P`1[!$_OP%5Q!\``$!DZ^_Q
M$``$Q"P``$!>!_ZG&```I_3_],0L``!`5@?^!P<'!^OO\'``)./P_V#_<<#E
M___WLL#E___U_^PH``8`?.,@(```!.OO\1``!`?^!P<'!^MO\#``)+D$`++C
M\/]@_W'`(```$<G`Y?__^@&Y!``[["@`"0!\N00`8I4`(`"G=``+P"```!&X
MZV_PT``$P/3___M)P.7___5^["8`+0!\IP@``+D$`!NR7@`AIQ3__KD$`#:G
M&0``LEX`$Z<4__ZY"0`6N0D`*T$B$`+`Y?__].+`,```$:.Y!`"BP%```!$J
MN00`2\#E___W%;D$`#JG]/_)ZV_PT``$!_X'!P<'ZV_P,``DX_#^&/=QXQ#Q
MX`AQLD\`<.MW`"``#;)/`''2!Q``<"C`$```/\VY!`""P"```!#TT@_PL!`(
MT@?PP!`8TB_PX!`@T@_PR!!0T@?PV!!@P.7___F*["@`'P!\N00`LI4`(`"G
MA``8P.7___]RXQ#QX`AQU0<0`'`HIX0`!<#E___V][D$`"OK;_(8"`3`]/__
M]-_`Y?___T2Y!`"R["8`)0!\0:#PR.,@H````J=T``?`L```$2:G]``8P.7_
M__E4["8`!P!\IZL`"*?T_^Z5`"``IX3_^L#E___TNKD$`++L*/_S`'RG"```
MN00`&Z<I``"R7@`AIQ3__KD)`"OK(@`!``VG*P`!P.7___1!N00`8KD$`*+C
M0+```)3L1@";`'Y!H/#@X["@```"IX0`';D$`"O`Y?__^1>Y!`"R["@`F@!\
ME0`@`*>$`)7`Y?__^A_L*`"0`'ZY!``KP.7___1WN00`LD&@\+#LM@`,`'SC
MD*````*GA``&E0"0`*=T`'ZG"```N00`&Z>9``"R7@"1IQ3__KD$`":G&0``
MLEX`$J<4__ZY"0`6N0D`FQJ1IYH$!+D4`)FY!``IP.7___/GXV#PH``DN00`
MHL`P```0HL!@```0G,!0```0*KD$`$O`Y?__]A2G.0'`N00`*L#E___UK>PF
M`%7_?L#E___UEUA@(`#L:`!-$7[$&```/INY%`!FN00`6N-`@```!,`P```0
M?>,@$```!,#E___U#Z>Y``#C$/'@"''5!Q``<"BG=/\=N00`*^MO\A@(!`?^
MN00`*KD4`$3`,```$%7`Y?__]=5!L+`!0:"@`J?T_U2GJP`(I_3_6+D$`"G`
MY?__^8;L*``*`'ZY!``IP.7___/>N00`LJ>K``BG]/]G03#Q$+D$`"K`Y?__
M\[$8TNPH`!8`?L08```^1KD$`%KC0(````3`,```$$CC(!````3`Y?__]+RG
M]/^M6!#Q**<H0`#`&P``\`#L$O_F8'98L/$LP.7___7+[++_WF!V6!#Q**<H
M`<#`&P```?_L$O_48':Y!``IP.7___,YN00`LL`@```01,#E___X';D$`#+L
M)@#&`'SCD(````2G"```IQD``+D$`"FR7@`2IQ3__KD)`!GL'``^`WZY%``A
MXS*?_/]QP"```!`ELET`(Z<4__ZG=``O[!@`#01^IQK_^[D4`!%!$9``E2\0
M`*=T`"+C$(`(``*GA``=IP@``*<I``"Y!``QLEX`(Z<4__ZY"0`A["P`#P-]
MXS(?_/]QP"````_[LET`(Z<4__ZYXH"1P.7___UL["8`V`!^N00`*:<Y``#`
MY?__\T*Y!`"2&(+L*`#+`'ZG20`"ISG_[D%@\>#`Y?__\F.G20`&N00`-KD$
M`"G`Y?__]%J5`/'@IW0`7)5#\>&G=`!8E4'QXJ=T`%250_'CIW0`4)5(\>2G
M=`!,E47QY:=T`$BG20`"ISG_QKD$`"G`Y?__\CFG20`IN00`-KD$`"G`Y?__
M]##`$```$`+C$/"@`"3`4```#MBY!`!*P#````^;N00`*\#E___TO;D$`"K`
MY?__]&BY!``[P"````ZWP.7___BXN00`*\#E___]2Z?T_K[C((````3`Y?__
M^I>Y!`"2[";_.`!\I_3_,J=)``"G.0``N00`*<#E___Q\\#E```,Q+D4`(BY
M!`#2I4^``+D$`#:Y!``HP.7___/C["(`-`!^N00`*$&0\:-!@/&WP.7___.W
MN00`/;D$`"FY!`#8P.4```V"IVD`%.-`D```D+D$`"C`,```#N'`Y?__]&&G
MFP`!IXL``J=G__'`$```#XV2`/'?XQ#PH``DN00`;:?T_X>Y%`!"N00`-KD$
M`"W`Y0``#+*G]/^ZP#````ZQP"````YPP.7___A#P.7___&HP!````]JN00`
M8N,0\*``),!0```./KD$`$K`,```#PFY!``KP.7___0CISD!P+D$`"O`Y?__
M\[SL)O]?_W[`Y?__\Z98$"``IQX`$:=T_U7`Y?__\7W`$```#S_C$/"H`"2G
MV@`!N10`';D$`&+C$/"@`"3`4```#@RY!`!*P#````[>N00`*\#E___S\:?T
M_\[KG_!(`"3C\/]@_W'$J```/)KC(*```!;`Y?__\]"Y!`"RXR"@```6P.7_
M__/(T@`@L;"PP"````WVP.7___9[["@`"P!\E3$@`*=T``:5`"`!IX0`!<#E
M___[3<2H```\<N,@H```%L#E___SJ*=9``.G20`!P#````ZBP.7___(.N00`
MLNPH`"X`?.,@H```%L#E___SD^,0L!``!,!````.C^,P$```!,#E___R%^,0
ML!``!.,0$```!)%`$`VGA``1XR"@```6P.7___-WXQ"P$``$XS`0```$P.7_
M__$>Q)@``#POXR"0```6P.7___-EIUD``Z=)``'`,```#F/`Y?__\<NY!`"R
M["@`/P!\P"````ULP.7___8,N00`HNPH`!8`?.,@D```%L#E___S1>,0L!``
M!+D$`$KC,!````3`Y?__\<JG]``@P.7___BUN00`HN,@D```%NRH`%\`?,#E
M___S*N,0L!``!+D$`$KC,!````3`Y?__\:^Y!``JP.7___+:Q+@``#O;XR"P
M```6P.7___,1N00`HN,@L```%L#E___S":=)``'`,```#@K`Y?__\!'`0```
M#@^Y!``RN00`*L#E___QA^,@L```%L#E___R\9(`(+'`(```#0#`Y?__]:7$
M*P``/"[L)@`C`'S$*```/"3`Y?__^^7$*P``/"+L)@`7`'S`(```#>C`Y?__
M\"'`Y?__\L[$.```/`_C$+`0``3C0#````2G]/^%ISD!P,0H```\!L#E___R
M:[D$`%+L*``8$7[L$@`!`-CL'``2`7_$&```._'$2```._+C,!````3`(```
M#<G`Y?__[_'KG_#H``0'_@<'!P?KK_!0`"3C\/]@_W&Y!`"RP.7___F8P.7_
M__F!N00`HL#E___ZZ.PH`!T`?NRX`!H`?)4`L`"GA``5P#````T+N00`*L#E
M___PQNRB``M@9+D$`"OKK_#P``3`]/__]8_KK_#P``0'_K)/`!#K$0`@``VR
M3P`1ZV_P,``DIUD`"./P_-#_<=('\R@0**>Y``!!$/"HN00`,>-+(#@`!.L$
M`"``#.,`,```),!*`````.-`,`@`)*>[``BG.P`0IU?_[:=)`$#C,!!H``3C
M,!!``(+C,!`0`(+C,!```(+L4R"_(57L4R`^`5;C4!"``"2G&P`(IT?_Z>,0
M(!@`!.,0\*``).,0\*@`!,(:6H)YF>,0("``".,P(```!.-`(!``!.,`(`@`
M!.RS(+\E5>RS(#H%5KD(`+'C$/"@``2YYQ`4N8``$.,0\*``@N.0\+``!+D(
M`+'"FEJ">9GL>R"_`%7CD/"@``CLNSN_)57K$``"``SLMP`Z!5;L$``A'E;C
M4/#```3LT2"_`%7"6EJ">9FYY]"DN8``H[F"`*2Y"`"IN0@`J^R*(+\`5>RJ
M.[\E5>RH`#H%5NNS``(`#..0\+@`!.RS`"$>5L*:6H)YF>QK(+\`5;F"`!NY
M"`"4N8``%[F"`!VY"`#5N0@`&>-0\,@`!+D(`!K"6EJ">9GKIP`"``SLIP`A
M'E:Y@@"ZN8``N+F"`+:Y"`"][)$@OP!5['H@OP!5N0@`9>P1.[\E5>-0\-``
M!.P9`#H%5L):6H)YF;D(`!OKN``"``SLN``A'E:Y@@"KN8``J;F"`*>Y"`"F
M[-$@OP!5[(L@OP!5N0@`=>P1.[\E5>-0\-@`!.P=`#H%5L):6H)YF;D(`!KK
MJ0`"``SLJ0`A'E:Y@@"ZN8``O;F"`+BY"`"W[&$@OP!5[)H@OP!5N0@`A>P1
M.[\E5>-0\.``!.P6`#H%5L):6H)YF;D(`!OKO0`"``SLO0`A'E:Y@@"KN8``
MIKF"`*FY"`"H['$@OP!5[-L@OP!5N0@`E>P1.[\E5>-0\.@`!.P7`#H%5L):
M6H)YF;D(`!KKI@`"``SLI@`A'E:Y@@"ZN8``M[F"`+VY"`"Y[($@OP!5[&H@
MOP!5N0@`U>P1.[\E5>-0\/``!.P8`#H%5L):6H)YF;D(`!OKMP`"``SLMP`A
M'E:Y@@"KN8``J+F"`*:Y"`"M[)$@OP!5['L@OP!5N0@`9>P1.[\E5>-0\/@`
M!.P9`#H%5L):6H)YF;D(`!KKJ``"``SLJ``A'E:Y@@"ZN8``N;F"`+>Y"`"V
M[-$@OP!5[(H@OP!5N0@`=>P1.[\E5>-0\0``!.P=`#H%5L):6H)YF;D(`!OK
MN0`"``SLN0`A'E:Y@@"KN8``K;F"`*BY"`"G[&$@OP!5[)L@OP!5N0@`A>P1
M.[\E5>-0\0@`!.P6`#H%5L):6H)YF;D(`!KKK0`"``SLK0`A'E:Y@@"ZN8``
MMKF"`+FY"`"X['$@OP!5[-H@OP!5N0@`E>P1.[\E5>-0\1``!.P7`#H%5L):
M6H)YF;D(`!OKM@`"``SLM@`A'E:Y@@"KN8``I[F"`*VY"`"I[($@OP!5[&L@
MOP!5N0@`U>P1.[\E5>-0\1@`!.P8`#H%5L):6H)YF;D(`!KKIP`"``SLIP`A
M'E:Y@@"ZN8``N+F"`+:Y"`"][)$@OP!5['H@OP!5N0@`9>P1.[\E5>-0\2``
M!.P9`#H%5L):6H)YF;D(`!OKN``"``SLN``A'E:Y@@"KN8``J;F"`*>Y"`"F
M[-$@OP!5[(L@OP!5N0@`=>P1.[\E5>-0\2@`!.P=`#H%5L):6H)YF;D(`!KK
MJ0`"``SLJ0`A'E:Y@@"ZN8``O;F"`+BY"`"W[&$@OP!5[)H@OP!5N0@`A>P1
M.[\E5>-0\3``!.P6`#H%5L):6H)YF;D(`!OKO0`"``SLO0`A'E:Y@@"KN8``
MIKF"`*FY"`"H['$@OP!5[-L@OP!5N0@`E>P1.[\E5>-0\3@`!.P7`#H%5L):
M6H)YF;D(`!KKI@`"``SLI@`A'E:Y@@"ZN8``M[F"`+VY"`#5N0@`N>R!(+\`
M5>QJ(+\`5>P1.[\E5>P8`#H%5KD(`!OKMP`"``SLMP`A'E:Y@@"KN8``J+F"
M`*:Y"`"M[-$[OR55[-$@.@56[)$@OP!5N0@`K>Q[(+\`5>O8``(`#.S8`"$>
M5KGGT!OCL/%```3"NEJ">9FY"`"VN8``&>N)``(`#+F"`!?LB0`A'E:Y"``;
MN>>`G>RZ.[\E5;F"`)KLNB`Z!5:Y"``;X[#Q2``$PKINV>NAN0@`M^QZ(K\^
M5;D:`+GL>@(A'E;LD3N_)56YYW"H[)$@.@56N8(`H;D(`+GL82*_/E7CD/%0
M``3L80(A'E;"FF[9ZZ&Y&@"=N1H`FNRK.[\E5>RK(#H%5KD(`)KCH/%8``3"
MJF[9ZZ&YYV`7N8(`&[D:`*BY&@"A[!D[OR55[!D@.@56[(LBOSY5N0@`H>R+
M`B$>5KGG@!:Y@@`9X[#Q8``$PKINV>NAN1H`M^QY(K\^5;D:`+'L>0(A'E;L
M&CN_)56YYW"8[!H@.@56N8(`FKD(`+'C$/%H``3"&F[9ZZ&Y&@`6N1H`&>R;
M.[\E5>R;(#H%5KD(`!GLFB*_/E7LF@(A'E;CH/%P``3"JF[9ZZ&Y&@"HN>>0
MA[F"`(NY&@"H[($[OR55[($@.@56N0@`J.R+(K\^5>R+`B$>5N.P\7@`!,*Z
M;MGKH;D:`+>YYX!YN8(`<;D:`+?L>CN_)57L>B`Z!5:Y"`"W['$BOSY5['$"
M(1Y6XQ#Q@``$PAINV>NAN1H`&;GG<)BY@@":N1H`&>R;.[\E5>R;(#H%5KD(
M`!GLFB*_/E7LF@(A'E;CH/&(``3"JF[9ZZ&Y&@"HN>>0A[F"`(NY&@"H[($[
MOR55[($@.@56N0@`J.R+(K\^5>R+`B$>5N.P\9``!,*Z;MGKH;D:`+>YYX!Y
MN8(`<;D:`+?L>CN_)57L>B`Z!5:Y"`"W['$BOSY5['$"(1Y6XQ#QF``$PAIN
MV>NAN1H`&;GG<)BY@@":N1H`&>R;.[\E5>R;(#H%5KD(`!GLFB*_/E7LF@(A
M'E;CH/&@``3"JF[9ZZ&Y&@"HN>>0A[F"`(NY&@"H[($[OR55[($@.@56N0@`
MJ.R+(K\^5>R+`B$>5N.P\:@`!,*Z;MGKH;D:`+>YYX!YN8(`<;D:`+?L>CN_
M)57L>B`Z!5:Y"`"W['$BOSY5['$"(1Y6XQ#QL``$PAINV>NAN1H`&;GG<)BY
M@@":N1H`&>R;.[\E5>R;(#H%5KD(`!GLFB*_/E7LF@(A'E;CH/&X``3"JF[9
MZZ&Y&@"HN>>0A[F"`(NY&@"H[($[OR55[($@.@56N0@`J.R+(K\^5>R+`B$>
M5N.P\<``!,*Z;MGKH;D:`+>YYX!YN8(`<;D:`+?L>CN_)57L>B`Z!5:Y"`"W
M['$BOSY5['$"(1Y6XQ#QR``$PAINV>NAN1H`&;GG<)BY@@":N1H`&>R;.[\E
M5>R;(#H%5NQJ(K\^5;D(`!GL:@(A'E:YYV"7N8(`F^.@\=``!,*J;MGKH;D:
M`*BY&@"I[)$[OR55[)$@.@56N0@`J>R;(K\^5>R;`B$>5KGGD+:Y@@"Q[(H@
MOP!5X]#QV``$PMINV>NAN1H`U[D:`-OLNCN_)57LN``Z!5:Y"`#;[+$BOSY5
M[+$"(1Y6XQ#QX``$PAINV>NAN1H`%K/!``&YY[`9N8(`&K/-`*#L?2"_`%7L
MW3N_)56Y&@"A[-<`.@56ZQ@``@`,N0@`K>P8`"$>5NQJ(+\`5>R!(+\`5>RJ
M.[\E5;GD@%OLI@`Z!5:YYA#;N8``U[F!`-7C4/'H``3"6H\;O-RY&@!9N0@`
MU;D(`-KKIP`"``SLIP`A'E:YY(!ZN8$`&KF``!:Y@0`7XW#Q\``$PGJ/&[S<
MN1H`>^R=(+\`5;GH<+'LW3N_)57K%@`"``SLV0`Z!5;L%@`A'E:Y"`"][&$@
MOP!5['L@OP!5N>1@6NR[.[\E5>RW`#H%5KGF$-JY@`#9N8$`U>-0\?@`!,):
MCQN\W+D(`(6Y"`#8N0@`V^NY``(`#.RY`"$>5KGD8)NY@0`;N8``%[F!`!GC
MD/(```3"FH\;O-RY&@":[(T@OP!5N>B0H>S=.[\E5>L7``(`#.S8`#H%5NP7
M`"$>5KD(`*WL<2"_`%7LFB"_`%6YY'!;[*H[OR55[*D`.@56N>80V[F``-BY
M@0#5XU#R"``$PEJ/&[S<N0@`9;D(`-:Y"`#:ZZ@``@`,[*@`(1Y6N>1PBKF!
M`!JY@``9N8$`&..`\A``!,**CQN\W+D:`(OL;2"_`%6YZ("Q[-T[OR55[-8`
M.@56N0@`O>R+(+\`5>L9``(`#.P9`"$>5NR[.[\E5>R1(+\`5>RX`#H%5KGD
MD%JYYA#:N8``UKF!`-7C4/(8``3"6H\;O-RY"`!UN0@`U[D(`-OKM@`"``SL
MM@`A'E:YY)!KN8$`&[F``!BY@0`6XV#R(``$PFJ/&[S<N1H`:NQ](+\`5;GH
M8*'LW3N_)57K&``"``SLUP`Z!5;L&``A'E:Y"`"M[($@OP!5[&H@OP!5N>2`
M6^RJ.[\E5>RF`#H%5KGF$-NY@`#7N8$`U>-0\B@`!,):CQN\W+D(`)6Y"`#9
MN0@`VNNG``(`#.RG`"$>5KGD@'JY@0`:N8``%KF!`!?C</(P``3">H\;O-RY
M&@![[)T@OP!5N>APL>S=.[\E5>L6``(`#.S9`#H%5NP6`"$>5KD(`+WL82"_
M`%7L>R"_`%6YY&!:[+L[OR55[+<`.@56N>80VKF``-FY@0#5XU#R.``$PEJ/
M&[S<N0@`A;D(`-BY"`#;Z[D``@`,[+D`(1Y6N>1@F[F!`!NY@``7N8$`&>.0
M\D``!,*:CQN\W+D:`)KLC2"_`%6YZ)"A[-T[OR55ZQ<``@`,[-@`.@56[!<`
M(1Y6N0@`K>QQ(+\`5>R:(+\`5;GD<%OLJCN_)57LJ0`Z!5:YYA#;N8``V+F!
M`-7C4/)(``3"6H\;O-RY"`!EN0@`UKD(`-KKJ``"``SLJ``A'E:YY'"*N8$`
M&KF``!FY@0`8[&T@OP!5XX#R4``$[-T[OR55PHJ/&[S<[-8`.@56N1H`B[GH
M@+'K&0`"``SL&0`A'E;LD2"_`%6YY)!:N0@`O;GF$-JY@`#6N8$`U>-0\E@`
M!,):CQN\W+D(`'6Y"`!][(L@OP!5[+L[OR55[+@`.@56N0@`M^MV``(`#.S;
M(+\`5>QV`"$>5NR[.[\E5;GDD&?LO0`Z!5:Y@0`7N8``&+F!`!;C8/)@``3"
M:H\;O-RY&@!JN0@`%KD(`!OKN``"``SLN``A'E;LBR"_`%6YY(!7N>:P9[F`
M`&VY@0!EXU#R:``$PEJ/&[S<N0@`E;D(`);LH2"_`%7L$3N_)57L&@`Z!5:Y
M"``9ZYT``@`,[&$@OP!5[)T`(1Y6[!$[OR55N>2`V>P6`#H%5KF!`+FY@`"Z
MN8$`O>/0\G``!,+:CQN\W+D:`->Y"`"]N0@`L>L:``(`#.P:`"$>5NRA(+\`
M5;GDH%FYYA#9N8``UKF!`-7C4/)X``3"6H\;O-RY"`"%N0@`C>Q[(+\`5>S;
M.[\E5>S;(#H%5KGHT+CKA@`"``SLA@`A'E:YY*!HN8$`&+F``!>Y@0`6XV#R
M@``$PFJ/&[S<N1H`:>R;.[\E5>R;(#H%5KD(`!;K9P`"``RY"``9[&<`(1Y6
MXY#RB``$N>=@>,*:RF+!UKF"`'NY"`":[*$[OR55[*$@.@56N1H`E^Q[(K\^
M5;D(`)KL>P(A'E:YYW"FN8(`H>.P\I``!,*ZRF+!UKD:`+CL@2*_/E6Y&@"Z
M[($"(1Y6[*D[OR55N>>`%^RI(#H%5KF"`!FY"`"ZXZ#RF``$PJK*8L'6N1H`
MINQI(K\^5;D:`*'L:0(A'E;L&SN_)56YYV"8[!L@.@56N8(`F[D(`*'C$/*@
M``3"&LIBP=:Y&@`7N1H`&>R:.[\E5>R:(#H%5KD(`!GLFR*_/E7LFP(A'E;C
ML/*H``3"NLIBP=:Y&@"XN>>0AKF"`(JY&@"X[($[OR55[($@.@56N0@`N.R*
M(K\^5>R*`B$>5KGG@'FY@@!QXZ#RL``$PJK*8L'6N1H`IKD:`*?L>SN_)57L
M>R`Z!5:Y"`"G['$BOSY5['$"(1Y6XQ#RN``$PAK*8L'6N1H`&;GG<)BY@@";
MN1H`&>R:.[\E5>R:(#H%5KD(`!GLFR*_/E7LFP(A'E;CL/+```3"NLIBP=:Y
M&@"XN>>0A[F"`(JY&@"X[($[OR55[($@.@56N0@`N.R*(K\^5>R*`B$>5N.@
M\L@`!,*JRF+!UKD:`*>YYX!YN8(`<;D:`*?L>SN_)57L>R`Z!5:Y"`"G['$B
MOSY5['$"(1Y6XQ#RT``$PAK*8L'6N1H`&;GG<)BY@@";N1H`&>R:.[\E5>R:
M(#H%5KD(`!GLFR*_/E7LFP(A'E;CL/+8``3"NLIBP=:Y&@"XN>>0A[F"`(JY
M&@"X[($[OR55[($@.@56N0@`N.R*(K\^5>R*`B$>5N.@\N``!,*JRF+!UKD:
M`*>YYX!YN8(`<;D:`*?L>SN_)57L>R`Z!5:Y"`"G['$BOSY5['$"(1Y6XQ#R
MZ``$PAK*8L'6N1H`&;GG<)BY@@";N1H`&>R:.[\E5>R:(#H%5KD(`!GLFR*_
M/E7LFP(A'E;CL/+P``3"NLIBP=:Y&@"XN>>0A[F"`(JY&@"X[($[OR55[($@
M.@56N0@`N.R*(K\^5>R*`B$>5N.@\O@`!,*JRF+!UKD:`*>YYX!YN8(`<;D:
M`*?L>SN_)57L>R`Z!5:Y"`"G['$BOSY5['$"(1Y6XQ#S```$PAK*8L'6N1H`
M&;GG<)BY@@";N1H`&>R:.[\E5>R:(#H%5KD(`!GLFR*_/E7LFP(A'E;CL/,(
M``3"NLIBP=:Y&@"XN>>0A[F"`(JY&@"X[($[OR55[($@.@56N0@`N.R*(K\^
M5>R*`B$>5N.@\Q``!+GG@&G"JLIBP=:Y@@!AN1H`I[D:`*:Y!`!Z[*L[OR55
M[*L@.@56N0@`>NRA(K\^5>RA`B$>5N,0\Q@`!,(:RF+!UKD:`!FYYZ"8N8(`
MF^QG(+\`5;D:`!GLESN_)57LE@`Z!5:Y"``9[)LBOSY5[)L"(1Y6X[#S(``$
MPKK*8L'6[-$@OP!5N0@`.^P1.[\E5;GGD+KL'0`Z!5:Y&@`XN8(`M[D:`#NY
M"``3P!H`````XQ`@```DXZ`@(``(N0@`T..0\*``",#:`````./0(`@`),":
M`````..0(!@`),"J`````..@("``).L6``(`#.P6`"$>5KD(`!3`&@````#C
M$"`0`"2R3P`0ZQ$`(``-LD\`$=4'\R@0**>$``7`Y?__Z`3K;_-@``0'_@<'
MZ^_P<``DIRD`@./P_V#_<<#E___EA,`Q9T4C`>,P(```),`_[\VKB>,P(`@`
M),`_F+K<_N,P(!``),`Q$#)4=N5(("@``.,P(!@`).5((#```,`_P]+A\.5,
M('@``.,P("``).OO\1``!`?^!P<'!^MO\#``).L4``,`#;D$`**Y!`"TXR`@
M*``$N0@`$NQ!(+\`5>/P_V#_<;DQ`"&GQ``%ZP&@,`!ZXT"@*``DZQL`'0`,
MXQ"@,``(XQ"@,``D09"@..,0H'@`$J>$`#*GB`!`&X$9B[D$`"FY\C"+N1@`
M(;D4`$CL(P`'H&6YZ$`2N6%`,;GH0'/L(P`%P&6Y84`GP.7__^=;&!A:$*!X
M4!"@>.P6`#-`?KD$`"JY^8"+N10`N,#E___TQKD$`#?KBP`&`-ZGB@`!$KNG
M&``!N?)0@4%@H'BGA@`?[#D`!\!EN>BP&;EA0#'L.0`'H&6YZ+`3N6%`D;D$
M`$NY!``IP.7__^<E4+"@>.MO\-``!`?^I_0``>PY``;`9>PV__M`94%P,$#L
MDP`&P&7LE__S0&72/Y``,`"Y!``JI[K_P+D4`+O`Y?__]'^Y!``WI_3_Q>N/
M\$``)+D$`*+CD#`H``3C@#`P``3L*3J_/57L$@`!`-BY%``B02(P.)*`(`#C
M\/]@_W&Y%``AN00`LT%",#CL'`!9.'ZG*`!`IUD``+GY$!*Y!``DN18`,:=)
M``"H)```IQ3__KD$`"O`Y?__]$/7-[`XL#A"@+!S0I"P=^L8`!@`#$(0L'#K
M&``0``Q"$+!QZQ@`"``,0A"P<NL9`!@`#$(0L'3K&0`0``Q"$+!UZQD`"``,
M0A"P=KD$`"O`Y?__]!G2`Z``L`2Y!``KT@.@!+`,T@.@"+`4T@.@#+`<T@.@
M$+`DZX_PX``$P/3__^8FIR@`.*=9``"Y^1`2N00`)+D6`#&G20``J"0``*<4
M__ZG]/^R!P?$&```+2SL&``:_WSKO_!8`"3C\/]@_W'`L```+2`-X>.PO_C_
M<>,0L```!.P6__G_?.N_\/@`!`?^!_X'!P<'Z^_P<``DX_#_8/]QZ^_Q$``$
M!_X'!P<'Z^_P<``DN00`#Z?[_V#C`/```"3`Y?__Y^KK[_$0``0'_BX`+BX`
M`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5```97AE`"]P<F]C+R5I+R5S`%!!4E]414U0``!005)?4%)/
M1TY!344``#H`+P!015),-4Q)0@``4$523$Q)0@!015),-4]05```4$523$E/
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P``4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X``%!!4E]#3$5!3CT``#$`3$1?3$E"4D%265]0051(`%-94U1%30``
M)3`R>```<&%R+0``)7,E<R5S)7,``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@
M:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@``'!A<FP``"YP
M87(``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U
M+25U)7,``!@`<&5R;```,`!005(Z.E!A8VME<CHZ5D524TE/3@``,2XP-30`
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``"UE```M+0``55-%4@``55-%4DY!344``%1%35!$25(`5$U0
M`"]T;7```&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G
M;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ
M<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D8VAU;FM?<VEZ92`](#8T
M("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R!?1D@["FUY("1M86=I
M8U]P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[(",@3D]413H@
M)&UA9VEC7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE
M("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`[
M"G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!
M1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@
M/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@
M+3T@)&-H=6YK7W-I>F4["GT*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IS965K(%]&2"P@)&UA
M9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?
M<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@
M)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L
M<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C
M86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D
M36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I
M;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB
M=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN
M9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*
M?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)
M3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@
M)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN
M<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"G5N
M;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@
M9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=
M*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G
M<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@
M)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD
M(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N
M:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF
M("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!
M4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW
M:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?
M=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D
M,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@
M*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E
M<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I
M('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO
M9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B
M)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM
M>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*
M9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE
M("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&
M2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD
M=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC
M(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*
M:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D
M=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH
M)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT
M('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN
M960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N
M*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]
M"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM
M>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I
M;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN
M97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@
M(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD
M9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-2
M0S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=
M*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H
M(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI
M('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H
M+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F
M:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H
M95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV
M93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@
M)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R
M;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R
M-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@
M)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D
M9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0
M?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI
M<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@
M870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN
M9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E<BT^
M97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D
M9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S
M<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@
M+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A
M=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E
M;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL
M93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@
M)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER
M95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*
M<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N
M:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@
M4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@
M>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L
M('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C
M:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S
M:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q
M=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T[
M"GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M
M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.
M5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0
M("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E
M9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S
M97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H
M)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G
M:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*
M96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*
M?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM5
M4T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY
M("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%
M3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE
M*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K("1F:"P@
M+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@)&9H+"`D
M8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)'-Y<WM?
M9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L
M"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@
M)&UT:6UE.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M)&1I9V5S
M="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G
M/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R:71E("(D=&5M
M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A
M97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L
M;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B
M0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E
M(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@```!&P,[````U````!G__XV(```$U/__D9````#P
M__^20````2S__Y*(```!6/__DQ````&(__^4:````<3__Y3X```!]/__ER@`
M``(P__^7:````E#__Y?(```"C/__F,@```+(__^8T````MS__YJP```#&/__
MFM@```,L__^<`````U#__YV(```#?/__G?@```.H__^>*````\C__Y[8```$
M%/__I1````1D__^GF```!)C__Z@````%&/__O5````54__^]P```!7C__[\0
M```%M``````````4``````%Z4@`!>`X!&PP/H`$````````X````'/__D)@`
M``"N`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.P`("@@K/SLW,R\K)R,?&#J`!
M0@L````H````6/__D0P```!"`$:+"8P(C0>.!H\%1@[0`G3/SLW,RPZ@`0``
M`````"P```"$__^1*````(8`1HD+B@J+"8P(C0>.!H\%1@[0`@)XS\[-S,O*
MR0Z@`0```#@```"T__^1@````5@`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[8
M`P,!2L_.S<S+RLG(Q\8.H`$``````"P```#P__^2G````)``1HH*BPF,"(T'
MC@:/!48.V`,"@L_.S<S+R@Z@`0```````#@```$@__^2_````BH`1H8.APV(
M#(D+B@J+"8P(C0>.!H\%1@[0`@,"',_.S<S+RLG(Q\8.H`$``````!P```%<
M__^4\````#P`3(X&CP5&#L`"9,_.#J`!````.````7S__Y40````6@!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5&#L@"`DS/SLW,R\K)R,?&#J`!````````.```
M`;C__Y4T````_@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M!"`O#/SLW,R\K)
MR,?&#J`!````````$````?3__Y7X````!@`````````X```""/__E>P```'<
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.X",#`<[/SLW,R\K)R,?&#J`!````
M```0```"1/__EY`````B`````````"````)8__^7I````2(``N*.!H\%1@[`
M`E[/S@Z@`0```````"@```)\__^8J````8(`3(L)C`B-!XX&CP5&#O`"`P%N
MS\[-S,L.H`$`````*````JC__YH$````;`!:C@:/!48.P`)T"L_.#J`!2`M(
M#J`!SL\````````<```"U/__FD@````L`$:.!H\%1@[``E[/S@Z@`0```$@`
M``+T__^:6````*P`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[``FX*S\[-S,O*
MR<C'Q@Z@`48+`F;/SLW,R\K)R,?&#J`!``````!,```#0/__FKP```8X`$:&
M#H<-B`R)"XH*BPF,"(T'C@:/!48.B(4"`H8*S\[-S,O*R<C'Q@Z@`48+`P&^
M"L_.S<S+RLG(Q\8.H`%""P```#````.0__^@I````H0`1HD+B@J+"8P(C0>.
M!H\%1@[``@,"=L_.S<S+RLD.H`$````````X```#Q/__HO@```!H`$:*"HL)
MC`B-!XX&CP5&#L`"`DX*S\[-S,O*#J`!1@M&S\[-S,O*#J`!``````!````$
M`/__B*P```'\`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.V`(#`=@*S\[-S,O*
MR<C'Q@Z@`4(+`````````````#@```1$__^BX```%4X`6(8.APV(#(D+B@J+
M"8P(C0>.!H\%1@[0!P,5+L_.S<S+RLG(Q\8.H`$``````"````2`__^W]```
M`&P`2HX&CP5&#L`"`EK/S@Z@`0```````#@```2D__^X0````5``3(8.APV(
M#(D+B@J+"8P(C0>.!H\%7@[``@+D"L_.S<S+RLG(Q\8.H`%""P```#0```3@
M__^Y5````18`1H@,B0N*"HL)C`B-!XX&CP5N#L`"`K@*S\[-S,O*R<@.H`%&
M"P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#__________P``````````__________\````````````````````!
M`````````M,``````````0````````+>``````````\````````$"```````
M```,````````%[``````````#0```````%'P`````&___O4````````"&```
M```````%````````"]@`````````!@````````+P``````````H````````$
M)@`````````+`````````!@`````````%0````````````````````,`````
M``"ML``````````"````````!4``````````%``````````'`````````!<`
M```````2<``````````'````````$```````````"`````````)P````````
M``D`````````&``````````8````````````````;___^P`````(```!````
M`&____D`````````#@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````K!``````````````````````````````&`8````````8)@``
M`````!A&````````&&8````````8A@```````!BF````````&,8````````8
MY@```````!D&````````&28````````91@```````!EF````````&88`````
M```9I@```````!G&````````&>8````````:!@```````!HF````````&D8`
M```````:9@```````!J&````````&J8````````:Q@```````!KF````````
M&P8````````;)@```````!M&````````&V8````````;A@```````!NF````
M````&\8````````;Y@```````!P&````````'"8````````<1@```````!QF
M````````'(8````````<I@```````!S&````````'.8````````=!@``````
M`!TF````````'48````````=9@```````!V&````````':8````````=Q@``
M`````!WF````````'@8````````>)@```````!Y&````````'F8````````>
MA@```````!ZF````````'L8````````>Y@```````![X````````````````
M`````````````%'P`````````````````````````````!>P````````````
M````````````````````````````````````````````````````````````
M`````````````````````+``_____P````````````!4Z````````%(2````
M``````````````!2_@```````%,"````````5-P```````!29````````%3D
M``````````````````!4S````````%32``````````````````!4[D=#0SH@
M*$%L<&EN92`Q,2XR+C%?9VET,C`R,C`R,3DI(#$Q+C(N,2`R,#(R,#(Q.0``
M+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N9'EN86UI
M8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````
M````````````````````````````````````````````````````````````
M```````````+`````0`````````"`````````@`````````"```````````8
M`````````````````````0``````````````$V____8``````````@``````
M``(8`````````A@`````````V`````,```````````````@`````````````
M`!T````+``````````(````````"\`````````+P````````".@````$````
M`@`````````(`````````!@````E`````P`````````"````````"]@`````
M```+V`````````0F`````````````````````0``````````````+0````0`
M`````````@```````!``````````$``````````"<`````,`````````````
M``@`````````&````#<````$`````````$(````````2<````````!)P````
M````!4`````#````$0`````````(`````````!@```!!`````0`````````&
M````````%[`````````7L``````````H`````````````````````@``````
M````````/`````$`````````!@```````!?8````````%]@````````'(```
M``````````````````0`````````(````$<````!``````````8````````>
M^````````![X````````,O@````````````````````(``````````````!-
M`````0`````````&````````4?````````!1\``````````B````````````
M`````````@``````````````4P````$``````````@```````%(2````````
M4A(````````_7@````````````````````(``````````````%L````!````
M``````(```````"1<````````)%P`````````-0````````````````````$
M``````````````!I`````0`````````"````````DD@```````"22```````
M``48````````````````````"```````````````<P````$``````````P``
M`````*OP````````F_``````````$`````````````````````@`````````
M`````'H````!``````````,```````"L`````````)P``````````!``````
M```````````````(``````````````"!````!@`````````#````````K!``
M``````"<$`````````&@````!```````````````"``````````0````B@``
M``$``````````P```````*VP````````G;`````````"4```````````````
M``````@`````````"````(\````!``````````,```````"P`````````*``
M`````````'@````````````````````(``````````````"5````"```````
M```#````````L'@```````"@>````````!!@````````````````````"```
M````````````F@````$`````````,```````````````````H'@`````````
M,0````````````````````$``````````0````$````#````````````````
L`````````````*"I`````````*,````````````````````!````````````
